@@ -28,7 +28,7 @@ from typing import TYPE_CHECKING, Any, Generator, List, Optional, Sequence
 from ruamel.yaml import YAML  # type: ignore
 
 from ansiblelint.config import used_old_tags
-from ansiblelint.constants import RENAMED_TAGS
+from ansiblelint.constants import NESTED_TASK_KEYS, PLAYBOOK_TASK_KEYWORDS, RENAMED_TAGS
 from ansiblelint.file_utils import Lintable
 
 if TYPE_CHECKING:
@@ -69,7 +69,7 @@ def append_skipped_rules(
         yaml_skip = _append_skipped_rules(pyyaml_data, lintable)
     except RuntimeError:
         # Notify user of skip error, do not stop, do not change exit code
-        _logger.error('Error trying to append skipped rules', exc_info=True)
+        _logger.error("Error trying to append skipped rules", exc_info=True)
         return pyyaml_data
 
     if not yaml_skip:
@@ -97,25 +97,20 @@ def _append_skipped_rules(
     # parse file text using 2nd parser library
     ruamel_data = load_data(lintable.content)
 
-    if lintable.kind == 'meta':
-        pyyaml_data[0]['skipped_rules'] = _get_rule_skips_from_yaml(ruamel_data)
+    if lintable.kind in ["yaml", "requirements", "vars", "meta", "reno"]:
+        pyyaml_data[0]["skipped_rules"] = _get_rule_skips_from_yaml(ruamel_data)
         return pyyaml_data
 
     # create list of blocks of tasks or nested tasks
-    if lintable.kind in ('tasks', 'handlers'):
+    if lintable.kind in ("tasks", "handlers"):
         ruamel_task_blocks = ruamel_data
         pyyaml_task_blocks = pyyaml_data
-    elif lintable.kind == 'playbook':
+    elif lintable.kind == "playbook":
         try:
             pyyaml_task_blocks = _get_task_blocks_from_playbook(pyyaml_data)
             ruamel_task_blocks = _get_task_blocks_from_playbook(ruamel_data)
         except (AttributeError, TypeError):
-            # TODO(awcrosby): running ansible-lint on any .yml file will
-            # assume it is a playbook, check needs to be added higher in the
-            # call stack, and can remove this except
             return pyyaml_data
-    elif lintable.kind in ['yaml', 'requirements', 'vars', 'meta', 'reno']:
-        return pyyaml_data
     else:
         # For unsupported file types, we return empty skip lists
         return None
@@ -131,9 +126,9 @@ def _append_skipped_rules(
         if not pyyaml_task and not ruamel_task:
             continue
 
-        if pyyaml_task.get('name') != ruamel_task.get('name'):
-            raise RuntimeError('Error in matching skip comment to a task')
-        pyyaml_task['skipped_rules'] = _get_rule_skips_from_yaml(ruamel_task)
+        if pyyaml_task.get("name") != ruamel_task.get("name"):
+            raise RuntimeError("Error in matching skip comment to a task")
+        pyyaml_task["skipped_rules"] = _get_rule_skips_from_yaml(ruamel_task)
 
     return pyyaml_data
 
@@ -144,13 +139,6 @@ def _get_task_blocks_from_playbook(playbook: Sequence[Any]) -> List[Any]:
     :param playbook: playbook yaml from yaml parser.
     :returns: list of task dictionaries.
     """
-    PLAYBOOK_TASK_KEYWORDS = [
-        'tasks',
-        'pre_tasks',
-        'post_tasks',
-        'handlers',
-    ]
-
     task_blocks = []
     for play, key in product(playbook, PLAYBOOK_TASK_KEYWORDS):
         task_blocks.extend(play.get(key, []))
@@ -159,11 +147,6 @@ def _get_task_blocks_from_playbook(playbook: Sequence[Any]) -> List[Any]:
 
 def _get_tasks_from_blocks(task_blocks: Sequence[Any]) -> Generator[Any, None, None]:
     """Get list of tasks from list made of tasks and nested tasks."""
-    NESTED_TASK_KEYS = [
-        'block',
-        'always',
-        'rescue',
-    ]
 
     def get_nested_tasks(task: Any) -> Generator[Any, None, None]:
         for k in NESTED_TASK_KEYS:
@@ -179,26 +162,26 @@ def _get_tasks_from_blocks(task_blocks: Sequence[Any]) -> Generator[Any, None, N
 
 def _get_rule_skips_from_yaml(yaml_input: Sequence[Any]) -> Sequence[Any]:
     """Traverse yaml for comments with rule skips and return list of rules."""
-    yaml_comment_obj_strs = []
+    yaml_comment_obj_strings = []
 
     def traverse_yaml(obj: Any) -> None:
-        yaml_comment_obj_strs.append(str(obj.ca.items))
+        yaml_comment_obj_strings.append(str(obj.ca.items))
         if isinstance(obj, dict):
-            for key, val in obj.items():
+            for _, val in obj.items():
                 if isinstance(val, (dict, list)):
                     traverse_yaml(val)
         elif isinstance(obj, list):
-            for e in obj:
-                if isinstance(e, (dict, list)):
-                    traverse_yaml(e)
+            for element in obj:
+                if isinstance(element, (dict, list)):
+                    traverse_yaml(element)
         else:
             return
 
     traverse_yaml(yaml_input)
 
     rule_id_list = []
-    for comment_obj_str in yaml_comment_obj_strs:
-        for line in comment_obj_str.split(r'\n'):
+    for comment_obj_str in yaml_comment_obj_strings:
+        for line in comment_obj_str.split(r"\n"):
             rule_id_list.extend(get_rule_skips_from_line(line))
 
     return [normalize_tag(tag) for tag in rule_id_list]
